Struct erdnuss_comms::frame_pool::FrameStorage
source · pub struct FrameStorage<const N: usize> { /* private fields */ }Expand description
Storage for exactly N frames
Implementations
sourceimpl<const N: usize> FrameStorage<N>
impl<const N: usize> FrameStorage<N>
sourcepub fn take(&'static self) -> Option<RawFrameSlice>
pub fn take(&'static self) -> Option<RawFrameSlice>
Attempt to take the storage as a RawFrameSlice
The first call will return Some, all later calls will return None. Uses a critical section to ensure it only works once, even on targets without atomics